
1.  Goal

    PushPackageToPypi is a project which allow us to push our python programm on python packages community (pypi.org)

2.  Requirements

    -   packages installation :
        -   pip install build   
        -   pip install twine

3.  More details 

    -   [gitlab-Pypi](https://docs.gitlab.com/ee/user/packages/pypi_repository/)
    -   [Packaging-Python-Projects](https://packaging.python.org/en/latest/tutorials/packaging-projects/#creating-pyproject-toml)
    -   [Pypi-token](https://packaging.python.org/en/latest/specifications/pypirc/)